@@ -1,6 +1,6 @@
 package Test::Routine::Common;
 # ABSTRACT: a role composed by all Test::Routine roles
-$Test::Routine::Common::VERSION = '0.024';
+$Test::Routine::Common::VERSION = '0.029';
 use Moose::Role;
 
 #pod =head1 OVERVIEW
@@ -15,6 +15,12 @@ use Test2::API 1.302045 ();
 
 use namespace::autoclean;
 
+sub BUILD {
+}
+
+sub DEMOLISH {
+}
+
 sub run_test {
   my ($self, $test) = @_;
 
@@ -42,16 +48,28 @@ Test::Routine::Common - a role composed by all Test::Routine roles
 
 =head1 VERSION
 
-version 0.024
+version 0.029
 
 =head1 OVERVIEW
 
 Test::Routine::Common provides the C<run_test> method described in L<the docs
 on writing tests in Test::Routine|Test::Routine/Writing Tests>.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
