@@ -1,6 +1,6 @@
 package Test::Routine::Test::Role;
 # ABSTRACT: role providing test attributes
-$Test::Routine::Test::Role::VERSION = '0.028';
+$Test::Routine::Test::Role::VERSION = '0.029';
 use Moose::Role;
 
 has description => (
@@ -34,13 +34,14 @@ Test::Routine::Test::Role - role providing test attributes
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has the same support period as perl itself:  it supports the two
-most recent versions of perl.  (That is, if the most recently released version
-is v5.40, then this module should work on both v5.40 and v5.38.)
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -49,7 +50,7 @@ the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
