@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine::Util;
 # ABSTRACT: helpful exports for dealing with test routines
-$Test::Routine::Util::VERSION = '0.027';
+$Test::Routine::Util::VERSION = '0.029';
 #pod =head1 OVERVIEW
 #pod
 #pod Test::Routine::Util is documented in L<the Test::Routine docs on running
@@ -92,7 +92,7 @@ Test::Routine::Util - helpful exports for dealing with test routines
 
 =head1 VERSION
 
-version 0.027
+version 0.029
 
 =head1 OVERVIEW
 
@@ -104,9 +104,21 @@ composing given Test::Routine roles into a class and instance using
 L<Test::Routine::Compositor>, creating a L<Test::Routine::Runner> object and
 telling it to execute the tests on the test instance.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
